# Contribution Guide

- Issues will be enabled after releasing `v0.1.0`, until then please use Discussion.
- Run below commands before commiting changes
  ```commandline
  git add . && pre-commit run
  pytest tests/
  ```
